.. _publications:

***********************************
Publications related to Cratermaker
***********************************

Below is a list of publications and presentations related to the Cratermaker project. You can view them online or download the PDFs for offline reading.

- Minton, D.A. (2024) Cratermaker: A Modern Python-Based Cratered Terrain Evolution Model. LPSC 55 #2462. Abstract: `<https://www.hou.usra.edu/meetings/lpsc2024/pdf/2462.pdf>`_  Poster: `<https://www.datadepot.rcac.purdue.edu/daminton/Minton_LPSC2024-Cratermaker.pdf>`_
- Du, J., Minton, D.A., Blevins, A.M., Fassett, C.I., and Huang, Y.-H. (2024). Spectral Analysis of the Morphology of Fresh Lunar Craters I: Rim Crest, Floor, and Rim Flank Outlines. Journal of Geophysical Research: Planets 129, e2024JE008357. Paper: `<https://doi.org/10.1029/2024JE008357>`_
- Du, J., Minton, D.A., Blevins, A.M., Fassett, C.I., and Huang, Y.-H. (2025) Topographic Spectral Analysis of Two-dimensional Surface Elevations of the Continuous Ejecta, Wall, and floor of Fresh Lunar Craters. LPSC 56 #1201. Abstract: `<https://www.hou.usra.edu/meetings/lpsc2025/pdf/1201.pdf>`_ Poster: `<https://www.datadepot.rcac.purdue.edu/daminton/LPSC2025_CraterPSD_Du.pdf>`_
